@@ -57,7 +57,6 @@ def executable(browser: str, download: bool = False) -> str:
     :param browser: name of browser to get webdriver for
     :param download: download driver binaries if they don't exist
     """
-
     LOGGER.debug(
         "Webdriver initialization for '%s' (download: %s)", browser, download,
     )
@@ -70,19 +69,27 @@ def executable(browser: str, download: bool = False) -> str:
 
     driver_path = _driver_path(factory, download)
 
-    if not download:
-        LOGGER.info("Using already existing driver at: %s", driver_path)
-    elif not driver_path.exists():
+    if driver_path.exists() and not download:
+        LOGGER.debug("Attempting to use existing driver: %s", driver_path)
+        return str(driver_path)
+    elif driver_path.exists() and download:
+        # TODO: Implement version check for all browsers
+        if browser == "chrome":
+            chrome_version = _chrome_version()
+            driver_version = _chromedriver_version(driver_path)
+            if chrome_version != driver_version:
+                _download_driver(factory)
+        else:
+            LOGGER.debug(
+                "Driver download skipped, because it exists at '%s'", driver_path
+            )
+        return str(driver_path)
+    elif not driver_path.exists() and download:
         _download_driver(factory)
-    elif browser == "chrome":
-        chrome_version = _chrome_version()
-        driver_version = _chromedriver_version(driver_path)
-        if chrome_version != driver_version:
-            _download_driver(factory)
+        return str(driver_path)
     else:
-        LOGGER.info("Driver download skipped, because it exists at '%s'", driver_path)
-
-    return str(driver_path)
+        LOGGER.debug("Attempting to use driver from PATH")
+        return None
 
 
 def start(name: str, **options):
@@ -150,15 +157,13 @@ def _chromedriver_version(path: Path) -> str:
 
 def _download_driver(factory: Any, version: str = None) -> None:
     path = str(DRIVER_DIR)
-
-    LOGGER.info("Downloading webdriver to: %s", path)
     manager = factory(download_root=path, link_path=path)
 
     try:
         if version:
-            bin_path, _ = manager.download_and_install(version)
+            bin_path, _ = manager.download_and_install(version, show_progress_bar=False)
         else:
-            bin_path, _ = manager.download_and_install()
+            bin_path, _ = manager.download_and_install(show_progress_bar=False)
 
         if platform.system() == "Darwin" and bin_path:
             # TODO: Required for linux also?
